Changelog — django-markupmirror 0.1a2 documentation

### Navigation

- index
- modules |
- previous |
- django-markupmirror 0.1a2 documentation »

# Changelog

## 0.1 - unreleased

- Initial release including `MarkupMirrorField` field, `MarkupMirrorTextarea` and `AdminMarkupMirrorTextareaWidget` widgets and providing FeinCMS integration with `MarkupMirrorContent` Page content-type. Supported markup types are plain text, HTML, Mardown, reStructuredText and Textile.

### Navigation

- index
- modules |
- previous |
- django-markupmirror 0.1a2 documentation »